.. image:: ../../data/logo.png

|PyPI| |PyVersion| |License|

Welcome to the Font Bakery Documentation!
=========================================

Font Bakery is command-line tool for checking the quality of font projects.  

For a quick overview, check out the `list of checks <https://font-bakery.readthedocs.io/en/stable/fontbakery/profiles/index.html>`_ currently offered.

.. raw:: html

    <div style="position: relative; padding-bottom: 56.25%; height: 0; overflow: hidden; max-width: 100%; height: auto;">
        <iframe src="https://www.youtube.com/embed/vFjQEkJv9BQ" frameborder="0" allowfullscreen style="position: absolute; top: 0; left: 0; width: 100%; height: 100%;"></iframe>
    </div>

The project is licensed under the `Apache v2.0 license <https://github.com/fonttools/fontbakery/blob/main/LICENSE.txt>`_ and the source is available at https://github.com/fonttools/fontbakery.

.. toctree::
   :maxdepth: 2
   :caption: Product Overview

   product/Overview

.. toctree::
   :maxdepth: 2
   :caption: User Documentation

   user/installation/index
   user/USAGE
   user/bash-completion

.. toctree::
   :maxdepth: 2
   :caption: Developer Documentation

   developer/contrib-getting-started
   developer/writing-profiles
   developer/source-contrib-guide
   developer/doc-contrib-guide

.. toctree::
   :maxdepth: 2
   :caption: Maintainer Documentation
   
   maintainer/maintainer-notes

.. toctree::
   :maxdepth: 2
   :caption: Source Documentation
   
   fontbakery/index


Indices
=======

* :ref:`genindex`
* :ref:`modindex`


.. |PyPI| image:: https://img.shields.io/pypi/v/fontbakery.svg?style=flat
   :alt: Font Bakery PyPI Version
   :target: https://pypi.python.org/pypi/fontbakery/

.. |PyVersion| image:: https://img.shields.io/pypi/pyversions/fontbakery.svg?style=flat
   :alt: Python versions
   :target: https://pypi.python.org/pypi/fontbakery/

.. |License| image:: https://img.shields.io/badge/License-Apache%202.0-brightgreen.svg
   :alt: License
   :target: https://github.com/fonttools/fontbakery/blob/main/LICENSE.txt
